import pytest

from models import MatchingAlgorithm, ContentFilter, Content


@pytest.fixture
def content() -> Content:
    return Content(
        id=0,
        subscription_id=0,
        item_id="",
        item_guid="",
        item_url="",
        item_title="This week in the papers:",
        item_description="The price of petrol has risen by over 2% since the previous financial report. Read the full article here.",
        item_content_hash="",
        item_image_url=None,
        item_thumbnail_url=None,
        item_published=None,
        item_author="",
        item_author_url=None,
        item_feed_title="",
        item_feed_url=""
    )

@pytest.fixture
def content_filter() -> ContentFilter:
    return ContentFilter(
        id=0,
        server_id=0,
        name="Test Content Filter",
        matching_pattern="",
        matching_algorithm=MatchingAlgorithm.NONE,
        is_insensitive=True,
        is_whitelist=False   
    )

def test_content_filter_any(content: Content, content_filter: ContentFilter):
    content_filter.matching_pattern = "france twenty report grass lately"
    content_filter.matching_algorithm = MatchingAlgorithm.ANY
    assert content_filter.matches(content) is True

def test_content_filter_all(content: Content, content_filter: ContentFilter):
    content_filter.matching_pattern = "week petrol risen"
    content_filter.matching_algorithm = MatchingAlgorithm.ALL
    assert content_filter.matches(content) is True

def test_content_filter_regex(content: Content, content_filter: ContentFilter):
    content_filter.matching_pattern = r"\b(The Papers|weekly quiz)\b"
    content_filter.matching_algorithm = MatchingAlgorithm.REGEX
    assert content_filter.matches(content) is True
